
/*
 * In this Program you can Play/Pause song from Teensy GPIO Pin no 3. Once the played songs got completed for that particular day. The Teensy
 * will go to the Sleep Mode. But when Teensy is in sleep mode the Teensy still consumes 35mA, it is due to the Class A amplifier.
 * The songs will be played only on Thursday and Saturday. RTC Time may be 8min off
 * 
*/


//Thursday Songs will be played for 90mins. Saturday Songs will be played for 158mins

#include <Audio.h>
#include <Wire.h>
#include <SPI.h>
#include <SD.h>
#include <TimeLib.h>
#include <Bounce.h>
#include <play_sd_mp3.h>
#include <Snooze.h>

#define BUTTON 3  //Play Pause Pin3 of Teensy is used for Play/Pause.

tmElements_t tm;          //This is used for RTC

SnoozeDigital digital;
SnoozeUSBSerial usb;
SnoozeSPI sdCard;
SnoozeBlock config_teensy32(digital,usb,sdCard);  //Installing DeepSleep Drivers
 
Bounce bouncer = Bounce(BUTTON, 50); 

// GUItool: begin automatically generated code
AudioPlaySdMp3           playMp31;       //xy=154,78
AudioOutputI2S           i2s1;           //xy=334,89
AudioConnection          patchCord1(playMp31, 0, i2s1, 0);
AudioConnection          patchCord2(playMp31, 1, i2s1, 1);
AudioControlSGTL5000     sgtl5000_1;     //xy=240,153

// GUItool: end automatically generated code
byte thurs_trackmax = 9;   //Whenever the song plays it doesn't start with 0, after first song '1' is assigned to the next song and sequence goes on
byte sat_trackmax = 10;    //Whenever the song plays it doesn't start with 0, after first song '1' is assigned to the next song and sequence goes on
int sat_trackno = 0;
int thurs_trackno = 0;

bool track = true;
boolean trackchange;
boolean paused;

int who=0;

const char * saturdaylist[] = {
  "01SUPRA.mp3","02VIS.mp3", "03AMRU.mp3", "04CHAR1.mp3", "05CHAR2.mp3", "06CHAR3.mp3", "07CHAR4.mp3", "08SRINI.mp3","09BALAJI.mp3", "10JAI.mp3"  
};

const char * thursdaylist[] = {
  "11GHEUN.mp3","12DHOP.mp3", "13RUSO.mp3", "14SADAA.mp3","15ANANT.mp3", "16ACHYU.mp3", "17REHEM.mp3", "18NAMOH.mp3", "19SHYMS.mp3"
};

void setup() {

  //setTime(22,17,0,21,6,2021);    //  setTime(hours, minutes, seconds, days, months, years)
  setSyncProvider(getTeensy3Time);    
  Serial.begin(115200);
  delay(200);
  AudioMemory(6);
  sgtl5000_1.enable();
  sgtl5000_1.volume(0.68);

  SPI.setMOSI(7);
  SPI.setSCK(14);
  
  if (!(SD.begin(10))) {
    // stop here, but print a message repetitively
    while (1) {
      Serial.println("Unable to access the SD card");
      delay(500);
    }
  }

   if (timeStatus()!= timeSet) {
    Serial.println("Unable to sync with the RTC");
  } else {
    Serial.println("RTC has set the system time");
  }
  
  pinMode(BUTTON,INPUT_PULLUP); 

  digital.pinMode(21, INPUT_PULLUP, FALLING);     //pin, mode, type. These pins wakes up the Teensy from DeepSleep
  digital.pinMode(22, INPUT_PULLUP, FALLING);     //pin, mode, type. These pins wakes up the Teensy from DeepSleep  
  
}


void loop() {

 if (Serial.available()) {
    time_t t = processSyncMessage();
    if (t != 0) {
      Teensy3Clock.set(t); // set the RTC
      setTime(t);
    }
  }

 RTCSection(); 
 delay(500);


 
 if(weekday() == 7){          //Acutally '0' corresponds to Saturday, '1' corresponds to Sunday and so on

    if ((playMp31.isPlaying() == false) && (track == true)) {
    
    playFileSat(saturdaylist[sat_trackno]);
      
  }
 
 } else if(weekday() == 5){   // Here in Teensy 1=Sun,2=Mon......7=Saturday
  
       if ((playMp31.isPlaying() == false) && (track == true)) {
    
         playFileThu(thursdaylist[thurs_trackno]);    
  }
  
 }else{
  
       SIM_SCGC6 &= ~SIM_SCGC6_I2S;
       who = Snooze.sleep(config_teensy32);
  
  }
}

void playFileSat(const char *filename)
{
  thurs_trackno ++;
  sat_trackno ++;
  
  if(sat_trackno > sat_trackmax){
    SIM_SCGC6 &= ~SIM_SCGC6_I2S;  
    who = Snooze.sleep( config_teensy32 );    
  }
  Serial.print("Playing file: ");
  Serial.println(filename);
  
  playMp31.play(filename);

    // Simply wait for the file to finish playing.
  while (playMp31.isPlaying()) {
    // update controls!
    controls();
  }
  
  delay(100); // wait for library to parse WAV info

}


void playFileThu(const char *filename)
{
  thurs_trackno ++;
  sat_trackno ++;
   
  if(thurs_trackno > thurs_trackmax){
     SIM_SCGC6 &= ~SIM_SCGC6_I2S;
     who = Snooze.sleep( config_teensy32 );    
   }
 
  Serial.print("Playing file: ");
  Serial.println(filename);
  
  playMp31.play(filename);
      
  while (playMp31.isPlaying()) {
    // update controls!
    controls();
  }
  
  delay(100); // wait for library to parse WAV info

}

void controls() {
  
  bouncer.update();
  if ( bouncer.fallingEdge()) {  
    pausetrack();
  }
}

void pausetrack(){
  if(paused){
    Serial.println("Playing!");
  }
  else{
    Serial.println("Paused!");
  }
  paused = playMp31.pause(!paused);
}


  void RTCSection(){
  
    Serial.print("Time ");
    Serial.print(hour());
    printDigits(minute());
    printDigits(second());
    Serial.print(", Date: ");
    Serial.print(day());
    Serial.write('/');
    Serial.print(month());
    Serial.write('/');
    Serial.print(year());
    Serial.print(", WeekDay: ");
    Serial.print(weekday());
    Serial.println();
    
}

//Below function is for RTC 

void printDigits(int digits){
  // utility function for digital clock display: prints preceding colon and leading 0
  Serial.print(":");
  if(digits < 10)
    Serial.print('0');
  Serial.print(digits);
}

time_t getTeensy3Time()
{
  return Teensy3Clock.get();
}

/*  code to process time sync messages from the serial port   */
#define TIME_HEADER  "T"   // Header tag for serial time sync message

unsigned long processSyncMessage() {
  unsigned long pctime = 0L;
  const unsigned long DEFAULT_TIME = 1357041600; // Jan 1 2013 

  if(Serial.find(TIME_HEADER)) {
     pctime = Serial.parseInt();
     return pctime;
     if( pctime < DEFAULT_TIME) { // check the value is a valid time (greater than Jan 1 2013)
       pctime = 0L; // return 0 to indicate that the time is not valid
     }
  }
  return pctime;
}
